OFFICIAL_OPERATORS = {
    "heroku": "bentoml/heroku-deploy",
    "aws-lambda": "bentoml/aws-lambda-deploy",
    "aws-sagemaker": "bentoml/aws-sagemaker-deploy",
    "aws-ec2": "bentoml/aws-ec2-deploy",
    "azure-functions": "bentoml/azure-functions-deploy",
    "azure-container-instances": "bentoml/azure-container-instances-deploy",  # noqa: E501
    "google-compute-engine": "bentoml/google-compute-engine-deploy",
    "google-cloud-run": "bentoml/google-cloud-run-deploy",
}
